@@ -81,6 +81,7 @@ class Chart(xmlwriter.XMLwriter):
         self.hi_low_lines = None
         self.up_down_bars = None
         self.legend_delete_series = None
+        self.smooth_allowed = False
 
         self._set_default_properties()
 
@@ -135,6 +136,9 @@ class Chart(xmlwriter.XMLwriter):
         # Set the trendline properties for the series.
         trendline = self._get_trendline_properties(options.get('trendline'))
 
+        # Set the line smooth property for the series.
+        smooth = options.get('smooth')
+
         # Set the error bars properties for the series.
         y_error_bars = self._get_error_bars_props(options.get('y_error_bars'))
         x_error_bars = self._get_error_bars_props(options.get('x_error_bars'))
@@ -182,6 +186,7 @@ class Chart(xmlwriter.XMLwriter):
             'y2_axis': y2_axis,
             'points': points,
             'error_bars': error_bars,
+            'smooth': smooth
         }
 
         self.series.append(series)
@@ -611,12 +616,17 @@ class Chart(xmlwriter.XMLwriter):
             'pitch_family': options.get('pitch_family'),
             'charset': options.get('charset'),
             'baseline': options.get('baseline', 0),
+            'rotation': options.get('rotation'),
         }
 
         # Convert font size units.
         if font['size']:
             font['size'] *= 100
 
+        # Convert rotation into 60,000ths of a degree.
+        if (font['rotation']):
+            font['rotation'] = 60000 * int(font['rotation'])
+
         return font
 
     def _list_to_formula(self, data):
@@ -1283,6 +1293,10 @@ class Chart(xmlwriter.XMLwriter):
         # Write the c:val element.
         self._write_val(series)
 
+        # Write the c:smooth element.
+        if self.smooth_allowed:
+            self._write_c_smooth(series['smooth'])
+
         self._xml_end_tag('c:ser')
 
     def _write_idx(self, val):
@@ -1307,6 +1321,12 @@ class Chart(xmlwriter.XMLwriter):
         elif series['name'] is not None:
             self._write_tx_value(series['name'])
 
+    def _write_c_smooth(self, smooth):
+        # Write the <c:smooth> element.
+
+        if smooth:
+            self._xml_empty_tag('c:smooth', [('val', '1')])
+
     def _write_cat(self, series):
         # Write the <c:cat> element.
         formula = series['categories']
@@ -2270,6 +2290,15 @@ class Chart(xmlwriter.XMLwriter):
 
         self._xml_empty_tag('a:bodyPr', attributes)
 
+    def _write_axis_body_pr(self, rotation):
+        # Write the <a:bodyPr> element for axis fonts.
+        attributes = []
+
+        if rotation is not None:
+            attributes.append(('rot', rotation))
+
+        self._xml_empty_tag('a:bodyPr', attributes)
+
     def _write_a_lst_style(self):
         # Write the <a:lstStyle> element.
         self._xml_empty_tag('a:lstStyle')
@@ -2906,7 +2935,7 @@ class Chart(xmlwriter.XMLwriter):
             return
 
         self._xml_start_tag('c:txPr')
-        self._xml_empty_tag('a:bodyPr')
+        self._write_axis_body_pr(font.get('rotation'))
         self._write_a_lst_style()
         self._xml_start_tag('a:p')
 
